document.addEventListener('DOMContentLoaded', () => {
  const spNews1 = document.getElementById('spNews_1');
  const spNews2 = document.getElementById('spNews_2');
  const spNews3 = document.getElementById('spNews_3');
  const spNewsButtonLeft = document.getElementById('spNews_button1');
  const spNewsButtonRight = document.getElementById('spNews_button2');
  const spNewsEnd = document.getElementById('spNews_end');
  const spNewsContainer = document.querySelector('.spNews_container');

  let spNewsState = 0; // Initialize the state
  let startX, startY, isSwiping = false;

  function updateState() {
    // Clear all potential dynamic classes first to reset state
    spNews1.classList.remove('spNews_hidden', 'spNews_younger-placeholder');
    spNews2.classList.remove('spNews_hidden', 'spNews_younger-placeholder');
    spNews3.classList.remove('spNews_hidden', 'spNews_younger-placeholder');

    // Apply new states based on spNewsState
    if (spNewsState === 0) {
      spNews1.setAttribute('data-state', 'link');
      spNews2.setAttribute('data-state', 'older');
      spNews3.setAttribute('data-state', 'older+');
      spNews3.classList.add('spNews_younger-placeholder');
      spNewsButtonLeft.style.display = "none";
      spNewsButtonRight.style.display = "flex";
      spNewsEnd.style.display = "none";
    } else if (spNewsState === 1) {
      spNews1.setAttribute('data-state', 'younger');
      spNews2.setAttribute('data-state', 'link');
      spNews3.setAttribute('data-state', 'older');
      spNewsButtonLeft.style.display = "flex";
      spNewsButtonRight.style.display = "flex";
      spNewsEnd.setAttribute('data-state', 'older+');
    } else if (spNewsState === 2) {
      spNews1.setAttribute('data-state', 'younger+');
      spNews2.setAttribute('data-state', 'younger');
      spNews3.setAttribute('data-state', 'link');
      spNewsButtonLeft.style.display = "flex";
      spNewsButtonRight.style.display = "flex";
      spNewsEnd.setAttribute('data-state', 'end');
      spNewsEnd.style.display = "flex";
      spNewsEnd.style.pointerEvents = "none";
    } else if (spNewsState === 3) {
      spNews2.setAttribute('data-state', 'younger+');
      spNews3.setAttribute('data-state', 'younger');
      spNewsButtonLeft.style.display = "flex";
      spNewsButtonRight.style.display = "none";
      spNewsEnd.setAttribute('data-state', 'link');
      spNewsEnd.style.display = "flex";
      spNewsEnd.style.pointerEvents = "auto";
    }
  }

  spNewsButtonLeft.addEventListener('click', () => {
    if (spNewsState > 0) {
      spNewsState--;
      updateState();
    }
  });

  spNewsButtonRight.addEventListener('click', () => {
    if (spNewsState < 3) {
      spNewsState++;
      updateState();
    }
  });

  // Adding touch swipe functionality
  spNewsContainer.addEventListener('touchstart', function(e) {
    startX = e.touches[0].clientX;
    startY = e.touches[0].clientY;
    isSwiping = false; // Reset isSwiping
  });

  spNewsContainer.addEventListener('touchmove', function(e) {
    let moveX = e.touches[0].clientX;
    let moveY = e.touches[0].clientY;
    if (!isSwiping) { // Prevent running excessively
      isSwiping = true;
      let deltaX = Math.abs(moveX - startX);
      let deltaY = Math.abs(moveY - startY);
      if (deltaX > deltaY && deltaX > 10) {
        e.preventDefault(); // Prevents horizontal scroll
      } else if (deltaY > deltaX && deltaY > 10) {
        e.preventDefault(); // Prevents vertical scroll
      }
    }
  });

  spNewsContainer.addEventListener('touchend', function(e) {
    let endX = e.changedTouches[0].clientX;
    let endY = e.changedTouches[0].clientY;
    handleGesture(endX, endY);
  });

  function handleGesture(endX, endY) {
    const isPortrait = window.matchMedia("(max-width: 600px) and (orientation: portrait)").matches;
    if (isPortrait) {
      // Vertical swipes
      if (endY - startY > 50) {
        if (spNewsState > 0) {
          spNewsState--;
          updateState();
        }
      } else if (startY - endY > 50) {
        if (spNewsState < 2) {
          spNewsState++;
          updateState();
        }
      }
    } else {
      // Horizontal swipes
      if (endX - startX > 50) {
        if (spNewsState > 0) {
          spNewsState--;
          updateState();
        }
      } else if (startX - endX > 50) {
        if (spNewsState < 2) {
          spNewsState++;
          updateState();
        }
      }
    }
  }
});
